@@ -1,8 +1,8 @@
 #!/usr/bin/python
 #
-#    $Id: iso9660.py,v 1.8 2006/03/24 18:07:22 rocky Exp $
+#    $Id: iso9660.py,v 1.11 2006/12/04 02:56:11 rocky Exp $
 #
-#    Copyright (C) 2006 Rocky Bernstein <rocky@cpan.org>
+#    Copyright (C) 2006 Rocky Bernstein <rocky@gnu.org>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ True is returned if path is valid."""
 
 
 def is_achar(achar):
-    """is_dchar(achar)->bool
+    """is_achar(achar)->bool
 
 Return 1 if achar is an ACHAR. achar should either be a string of 
 length one or the ord() of a string of length 1.
@@ -103,6 +103,16 @@ portion and the filename should be composed of only DCHARs.
 True is returned if path is valid."""
     return pyiso9660.pathame_valid(path)
 
+
+def pathname_isofy(path, version=1):
+    """pathname_valid_p(path, version=1)->string
+
+Take path and a version number and turn that into a ISO-9660 pathname.
+(That's just the pathname followed by ';' and the version number. For
+example, mydir/file.ext -> MYDIR/FILE.EXT;1 for version 1. The
+resulting ISO-9660 pathname is returned."""
+    return pyiso9660.pathname_isofy(path, version)
+
 def name_translate(filename, joliet_level=0):
     """name_translate(name, joliet_level=0)->str
 
@@ -380,7 +390,7 @@ class ISO9660:
         def stat(self, path, translate=False):
             """stat(self, path, translate=False)->{stat}
             
-            Return file status for path name psz_path. None is returned on
+            Return file status for path name path. None is returned on
             error.  If translate is True, version numbers in the ISO 9660
             name are dropped, i.e. ;1 is removed and if level 1 ISO-9660
             names are lowercased.
@@ -473,7 +483,7 @@ class ISO9660:
         def stat(self, path, translate=False):
             """stat(self, path, translate=False)->{stat}
             
-            Return file status for path name psz_path. None is returned on
+            Return file status for path name path. None is returned on
             error.  If translate is True, version numbers in the ISO 9660
             name are dropped, i.e. ;1 is removed and if level 1 ISO-9660
             names are lowercased.
